@@ -8,6 +8,7 @@
 
 #include <QLabel>
 #include <QPixmap>
+#include <QVariant>
 
 #include <memory>
 
@@ -68,6 +69,8 @@ public:
 
     QStringList formatsToSave() const override;
 
+    QObject *tests(const TestInterfacePtr &test) const override;
+
     void applySettings(QSettings &settings) override;
 
     void loadSettings(const QSettings &settings) override;
