@@ -10,8 +10,12 @@ void initSingleShotTimer(QTimer *timer, int milliseconds, const Receiver *receiv
     timer->setInterval(milliseconds);
 
     Q_ASSERT(receiver);
-    if (receiver)
-        QObject::connect( timer, &QTimer::timeout, receiver, slot, Qt::UniqueConnection );
+    if (!receiver)
+        return;
+
+    // Unique connection only works with member functions.
+    const auto flags = std::is_invocable<Slot&>() ? Qt::AutoConnection : Qt::UniqueConnection;
+    QObject::connect(timer, &QTimer::timeout, receiver, slot, flags);
 }
 
 #endif // TIMER_H
