@@ -171,4 +171,6 @@ void ActionHandler::showActionErrors(Action *action, const QString &message, ush
     notification->setTitle(title);
     notification->setMessage(msg, Qt::PlainText);
     notification->setIcon(icon);
+    notification->setUrgency(Notification::Urgency::High);
+    notification->setPersistency(Notification::Persistency::Persistent);
 }
