@@ -324,8 +324,7 @@ bool ClipboardBrowser::isFiltered(int row) const
         return true;
 
     const QModelIndex ind = m.index(row);
-    return m_filterRow != row
-            && m_sharedData->itemFactory
+    return m_sharedData->itemFactory
             && !m_sharedData->itemFactory->matches(ind, *filter);
 }
 
@@ -1019,7 +1018,7 @@ void ClipboardBrowser::dropEvent(QDropEvent *event)
     if (event->dropAction() == Qt::MoveAction && event->source() == this)
         return; // handled in mouseMoveEvent()
 
-    const QVariantMap data = cloneData( *event->mimeData() );
+    const QVariantMap data = cloneData( event->mimeData() );
     addAndSelect(data, m_dragTargetRow);
     m_dragTargetRow = -1;
 }
@@ -1303,38 +1302,45 @@ void ClipboardBrowser::filterItems(const ItemFilterPtr &filter)
 
     d.setItemFilter(filter);
 
-    // If search string is a number, highlight item in that row.
-    bool filterByRowNumber = !m_sharedData->numberSearch;
-    if (filterByRowNumber) {
-        m_filterRow = newSearch.toInt(&filterByRowNumber);
-        if (m_filterRow > 0 && m_sharedData->rowIndexFromOne)
-            --m_filterRow;
-    }
-    if (!filterByRowNumber)
-        m_filterRow = -1;
-
     int row = 0;
+    for ( ; row < length() && hideFiltered(row); ++row ) {}
+
+    const int firstVisibleRow = row;
+
+    for ( ; row < length(); ++row )
+        hideFiltered(row);
 
     if ( !filter || filter->matchesAll() ) {
-        for ( ; row < length(); ++row )
-            hideFiltered(row);
-
         scrollTo(currentIndex(), PositionAtCenter);
     } else {
-        for ( ; row < length() && hideFiltered(row); ++row ) {}
-
-        setCurrent(row);
-
-        for ( ; row < length(); ++row )
-            hideFiltered(row);
-
-        if ( filterByRowNumber && m_filterRow >= 0 && m_filterRow < m.rowCount() )
-            setCurrent(m_filterRow);
+        const int currentRow = currentRowFromSearch(newSearch, firstVisibleRow);
+        setCurrent(currentRow);
     }
 
     d.updateAllRows();
 }
 
+int ClipboardBrowser::currentRowFromSearch(const QString &search, int fallback)
+{
+    if (m_sharedData->numberSearch)
+        return fallback;
+
+    // If search string is a number, highlight item in that row.
+    bool ok;
+    int maybeRow = search.toInt(&ok);
+    if (!ok)
+        return fallback;
+
+    if (maybeRow > 0 && m_sharedData->rowIndexFromOne)
+        --maybeRow;
+
+    if (maybeRow < 0 || maybeRow >= m.rowCount())
+        return fallback;
+
+    setRowHidden(maybeRow, false);
+    return maybeRow;
+}
+
 void ClipboardBrowser::moveToClipboard(const QModelIndex &ind)
 {
     if ( ind.isValid() )
@@ -1378,11 +1384,15 @@ void ClipboardBrowser::keyPressEvent(QKeyEvent *event)
         return;
 
     // translate keys for vi mode
-    if (m_sharedData->viMode && handleViKey(event, this)) {
+    if (m_sharedData->navigationStyle == NavigationStyle::Vi && handleViKey(event, this)) {
         d.updateIfNeeded();
         return;
     }
 
+    // translate keys for emacs mode
+    if (m_sharedData->navigationStyle == NavigationStyle::Emacs && handleEmacsKey(event, this))
+        return;
+
     const Qt::KeyboardModifiers mods = event->modifiers();
 
     if (mods == Qt::AltModifier)
@@ -1390,6 +1400,16 @@ void ClipboardBrowser::keyPressEvent(QKeyEvent *event)
 
     const int key = event->key();
 
+    // WORKAROUND: Avoid triggering search with Ctrl+Space toggle selection action.
+    if (mods.testFlag(Qt::ControlModifier) && key == Qt::Key_Space) {
+        const QModelIndex current = currentIndex();
+        if (!edit(current, AnyKeyPressed, event)) {
+            selectionModel()->select(current, selectionCommand(current, event));
+            event->accept();
+            return;
+        }
+    }
+
     // This fixes few issues with default navigation and item selections.
     switch (key) {
     case Qt::Key_Up:
