@@ -37,7 +37,6 @@ ClipboardBrowser *ClipboardBrowserPlaceholder::createBrowser()
         return nullptr;
 
     std::unique_ptr<ClipboardBrowser> c( new ClipboardBrowser(m_tabName, m_sharedData, this) );
-    emit browserCreated(c.get());
 
     c->setStoreItems(m_storeItems);
     c->setMaxItemCount(m_maxItemCount);
@@ -53,10 +52,16 @@ ClipboardBrowser *ClipboardBrowserPlaceholder::createBrowser()
              this, &ClipboardBrowserPlaceholder::restartExpiring);
 
     m_browser = c.release();
+
+    emit browserCreated(m_browser);
+    if (!m_browser)
+        return nullptr;
+
     setActiveWidget(m_browser);
 
     restartExpiring();
 
+    emit browserLoaded(m_browser);
     return m_browser;
 }
 
