@@ -14,6 +14,21 @@ class Notification : public QObject
     Q_OBJECT
 
 public:
+    // Same values as KNotification::Urgency
+    enum class Urgency {
+        Default = -1,
+        Low = 10,
+        Normal = 50,
+        High = 70,
+        Critical = 90,
+    };
+
+    enum class Persistency {
+        Default = -1,
+        NonPersistent = 0,
+        Persistent = 1,
+    };
+
     explicit Notification(QObject *parent) : QObject(parent) {}
     virtual void setTitle(const QString &title) = 0;
     virtual void setMessage(const QString &msg, Qt::TextFormat format = Qt::PlainText) = 0;
@@ -23,6 +38,8 @@ public:
     virtual void setInterval(int msec) = 0;
     virtual void setOpacity(qreal opacity) = 0;
     virtual void setButtons(const NotificationButtons &buttons) = 0;
+    virtual void setUrgency(Urgency urgency) = 0;
+    virtual void setPersistency(Persistency persistency) = 0;
     virtual void adjust() = 0;
     virtual QWidget *widget() = 0;
     virtual void show() = 0;
