@@ -7,6 +7,7 @@
 #include "common/command.h"
 #include "gui/clipboardbrowser.h"
 #include "gui/notificationbutton.h"
+#include "gui/notification.h"
 
 #include <QList>
 #include <QMetaObject>
@@ -52,10 +53,22 @@ struct ItemSelection {
     QList<QPersistentModelIndex> indexes;
 };
 
+struct MessageData {
+    QString title;
+    QString message;
+    int timeoutMs = -1;
+    QString icon;
+    QString notificationId;
+    NotificationButtonList buttons;
+    Notification::Urgency urgency = Notification::Urgency::Default;
+    Notification::Persistency persistency = Notification::Persistency::Default;
+};
+
 Q_DECLARE_METATYPE(NamedValueList)
 Q_DECLARE_METATYPE(NotificationButtonList)
 Q_DECLARE_METATYPE(VariantMapList)
 Q_DECLARE_METATYPE(KeyboardModifierList)
+Q_DECLARE_METATYPE(MessageData)
 
 #if QT_VERSION < QT_VERSION_CHECK(6,0,0)
 Q_DECLARE_METATYPE(ClipboardMode)
@@ -71,6 +84,8 @@ QDataStream &operator<<(QDataStream &out, ClipboardMode mode);
 QDataStream &operator>>(QDataStream &in, ClipboardMode &mode);
 QDataStream &operator<<(QDataStream &out, KeyboardModifierList value);
 QDataStream &operator>>(QDataStream &in, KeyboardModifierList &value);
+QDataStream &operator<<(QDataStream &out, const MessageData &value);
+QDataStream &operator>>(QDataStream &in, MessageData &value);
 
 class ScriptableProxy final : public QObject
 {
@@ -126,12 +141,7 @@ public slots:
 
     void runInternalAction(const QVariantMap &data, const QString &command);
 
-    void showMessage(const QString &title,
-            const QString &msg,
-            const QString &icon,
-            int msec,
-            const QString &notificationId = QString(),
-            const NotificationButtonList &buttons = NotificationButtonList());
+    void showMessage(const MessageData &messageData);
 
     QVariantMap nextItem(const QString &tabName, int where);
     void browserMoveToClipboard(const QString &tabName, int row);
