@@ -48,8 +48,7 @@ private slots:
 
     void commandVisible();
     void commandToggle();
-    void commandHide();
-    void commandShow();
+    void commandShowHide();
     void commandShowAt();
     void commandFocused();
 
@@ -112,6 +111,8 @@ private slots:
     void commandScreenshot();
 
     void commandNotification();
+    void commandNotificationUrgency();
+    void commandNotificationPersistent();
 
     void commandIcon();
     void commandIconTag();
@@ -290,11 +291,11 @@ private slots:
 
     void actionDialogCancel();
     void actionDialogAccept();
-    void actionDialogSelection();
     void actionDialogSelectionInputOutput();
 
     void exitConfirm();
     void exitNoConfirm();
+    void exitStopCommands();
 
     void abortInputReader();
 
@@ -314,6 +315,9 @@ private slots:
 
     void saveLargeItem();
 
+    void slowClipboard();
+    void clipboardUriList();
+
 private:
     void clearServerErrors();
     int run(const QStringList &arguments, QByteArray *stdoutData = nullptr,
