@@ -2,10 +2,9 @@
 set -e
 
 distros=(
-    focal
     jammy
-    mantic
     noble
+    oracular
 )
 
 sed -i 's/quilt/native/' 'debian/source/format'
